#!/bin/bash

#author				: tsuren (hydrangea_and_snail@hotmail.com) -> original buildscript by hennes (jm@rapidrabbit.de)
#last changed		: 27-july-2007

#package			: blobwars - episode 2
#homepage			: http://www.parallelrealities.co.uk/blobAndConquer.php
#source location	: http://www.parallelrealities.co.uk/download.php?file=blobAndConquer-0.91-1.tar.gz&type=zip
#dependencies		: coreutils,cxxlibs,directfb,expat,fontconfig,freecxxlibs,freetype,gcc,gcc-g++,gdbm,glut,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,openssl,perl,sdl,SDL_gfx,sysfsutils,utempter,xorg,xterm,zlib

# ----- credentials
softname="blobwars2"
softversion="0.91"
srcurl="http://www.parallelrealities.co.uk/download.php?file=blobAndConquer-0.91-1.tar.gz&type=zip"
arch=i686
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
         |-----handy-ruler-----------------------------------------------|
blobwars2: blobwars - episode 2 (3d action game)
blobwars2:
blobwars2: With the apparent defeat of Galdov and the reclaiming of the
blobwars2: Fire, Time, Space and Reality Crystals the Blobs' battle was
blobwars2: only just beginning. Bob had rescued many Blobs and fought
blobwars2: many battles, but now he had an ever bigger task ahead of him.
blobwars2: The Blobs' homeworld is still littered with the alien forces
blobwars2: and Bob once again makes it his task to lead the counter
blobwars2: attack. But even without Galdov the aliens are still extremely
blobwars2: well organised ... They're Ready. Will You Be?
blobwars2:
EOF

# ----- extract source-archive
srcdir=blobAndConquer-$softversion
rm -rf $srcdir
if [ -f blobAndConquer-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c --output-document="$builddir/blobAndConquer-$softversion.tar.gz" $srcurl
fi
tar -zxvf blobAndConquer-$softversion.tar.gz
cd $srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- make & make install
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

sed -i 's|BINDIR = $(PREFIX)/games|BINDIR = $(PREFIX)/bin/|' \
  ./makefile
sed -i 's|DATADIR = $(PREFIX)/share/games/blobAndConquer|DATADIR = $(PREFIX)/share/blobwars2/|' \
  ./makefile
sed -i 's|DOCDIR = $(PREFIX)/share/doc/$(PROG)|DOCDIR = $(PREFIX)/doc/blobwars2-$(VERSION)/|' \
  ./makefile
sed -i 's|cp --preserve=timestamps icons/blobAndConquer.png $(ICONDIR)|cp --preserve=timestamps icons/blobAndConquer.png $(ICONDIR)/hicolor/48x48/apps/blobwars2.png|' \
  ./makefile
sed -i 's|cp --preserve=timestamps $(PROG) $(BINDIR)/$(PROG)|cp --preserve=timestamps $(PROG) $(BINDIR)/blobwars2|' \
  ./makefile

make $numjobs
	
make install DESTDIR=$dest

# ----- make .desktop-files
rm -f $dest/usr/share/applications/*
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Blob Wars 2: Blob And Conquer
Comment=Mission and Objective based 3D Action Game
Exec=blobwars2
Icon=blobwars2
Type=Application
Categories=Game;ArcadeGame;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
# ----- packaging
chown -R root.root $dest/usr/bin
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $package.dep
coreutils,cxxlibs,directfb,expat,fontconfig,freecxxlibs,freetype,gcc,gcc-g++,gdbm,glut,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,openssl,perl,sdl,SDL_gfx,sysfsutils,utempter,xorg,xterm,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
